def SayHello():
    print("Hello from MyPyPiPackage")
    return

def add(x,y):
    return x+y